netapp_ontap.resources.fc_login API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.fc_login`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

Fibre Channel (FC) logins represent connections formed by FC initiators that have successfully logged in to ONTAP. This represents the FC login on which higher-level protocols such as Fibre Channel Protocol and NVMe over FC (NVMe/FC) rely.
The Fibre Channel logins REST API provides information about active FC logins.

## Examples

### Retrieving all FC logins

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcLogin

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(FcLogin.get_collection()))

Try it out

    [
        FcLogin(
            {
                "_links": {
                    "self": {
                        "href": "/api/network/fc/logins/01056403-1383-bc4b-786a-93e8ea35969d/8b%3A21%3A2f%3A07%3A00%3A00%3A00%3A00"
                    }
                },
                "svm": {
                    "name": "svm1",
                    "uuid": "056403da-83a7-4b13-bc78-6a93e8ea3596",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/056403da-83a7-4b13-bc78-6a93e8ea3596"
                        }
                    },
                },
                "interface": {
                    "uuid": "01056403-1383-bc4b-786a-93e8ea35969d",
                    "_links": {
                        "self": {
                            "href": "/api/network/fc/interfaces/01056403-1383-bc4b-786a-93e8ea35969d"
                        }
                    },
                    "name": "lif1",
                },
                "initiator": {"wwpn": "8b:21:2f:07:00:00:00:00"},
            }
        ),
        FcLogin(
            {
                "_links": {
                    "self": {
                        "href": "/api/network/fc/logins/02056403-1383-bc4b-786a-93e8ea35969d/8c%3A21%3A2f%3A07%3A00%3A00%3A00%3A00"
                    }
                },
                "svm": {
                    "name": "svm1",
                    "uuid": "056403da-83a7-4b13-bc78-6a93e8ea3596",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/056403da-83a7-4b13-bc78-6a93e8ea3596"
                        }
                    },
                },
                "interface": {
                    "uuid": "02056403-1383-bc4b-786a-93e8ea35969d",
                    "_links": {
                        "self": {
                            "href": "/api/network/fc/interfaces/02056403-1383-bc4b-786a-93e8ea35969d"
                        }
                    },
                    "name": "lif2",
                },
                "initiator": {"wwpn": "8c:21:2f:07:00:00:00:00"},
            }
        ),
        FcLogin(
            {
                "_links": {
                    "self": {
                        "href": "/api/network/fc/logins/00056403-1383-bc4b-786a-93e8ea35969d/8a%3A21%3A2f%3A07%3A00%3A00%3A00%3A00"
                    }
                },
                "svm": {
                    "name": "svm2",
                    "uuid": "156403da-83a7-4b13-bc78-6a93e8ea3596",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/156403da-83a7-4b13-bc78-6a93e8ea3596"
                        }
                    },
                },
                "interface": {
                    "uuid": "03056403-1383-bc4b-786a-93e8ea35969d",
                    "_links": {
                        "self": {
                            "href": "/api/network/fc/interfaces/00056403-1383-bc4b-786a-93e8ea35969d"
                        }
                    },
                    "name": "lif3",
                },
                "initiator": {"wwpn": "8a:21:2f:07:00:00:00:00"},
            }
        ),
    ]

### Retrieving all FC logins with data protocol fcp in SVM svm1

The `svm.name` and `protocol` query parameters are used to perform the query.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcLogin

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(FcLogin.get_collection(protocol="fcp", **{"svm.name": "svm1"})))

Try it out

    [
        FcLogin(
            {
                "_links": {
                    "self": {
                        "href": "/api/network/fc/logins/01056403-1383-bc4b-786a-93e8ea35969d/8b%3A21%3A2f%3A07%3A00%3A00%3A00%3A00"
                    }
                },
                "protocol": "fcp",
                "svm": {
                    "name": "svm1",
                    "uuid": "056403da-83a7-4b13-bc78-6a93e8ea3596",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/056403da-83a7-4b13-bc78-6a93e8ea3596"
                        }
                    },
                },
                "interface": {
                    "uuid": "01056403-1383-bc4b-786a-93e8ea35969d",
                    "_links": {
                        "self": {
                            "href": "/api/network/fc/interfaces/01056403-1383-bc4b-786a-93e8ea35969d"
                        }
                    },
                    "name": "lif2",
                },
                "initiator": {"wwpn": "8b:21:2f:07:00:00:00:00"},
            }
        ),
        FcLogin(
            {
                "_links": {
                    "self": {
                        "href": "/api/network/fc/logins/02056403-1383-bc4b-786a-93e8ea35969d/8c%3A21%3A2f%3A07%3A00%3A00%3A00%3A00"
                    }
                },
                "protocol": "fcp",
                "svm": {
                    "name": "svm1",
                    "uuid": "056403da-83a7-4b13-bc78-6a93e8ea3596",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/056403da-83a7-4b13-bc78-6a93e8ea3596"
                        }
                    },
                },
                "interface": {
                    "uuid": "02056403-1383-bc4b-786a-93e8ea35969d",
                    "_links": {
                        "self": {
                            "href": "/api/network/fc/interfaces/02056403-1383-bc4b-786a-93e8ea35969d"
                        }
                    },
                    "name": "lif3",
                },
                "initiator": {"wwpn": "8c:21:2f:07:00:00:00:00"},
            }
        ),
    ]

### Retrieving all FC logins for initiators belonging to igroup1 and returning all of their properties

The `igroups.name` query parameter is used to perform the query. The `fields` query parameter is used to return all of the properties.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcLogin

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(FcLogin.get_collection(fields="*", **{"igroups.name": "igroup1"})))

Try it out

    [
        FcLogin(
            {
                "igroups": [
                    {
                        "uuid": "243bbb8a-46e9-4b2d-a508-a62dc93df9d1",
                        "_links": {
                            "self": {
                                "href": "/api/protocols/san/igroups/243bbb8a-46e9-4b2d-a508-a62dc93df9d1"
                            }
                        },
                        "name": "igroup1",
                    }
                ],
                "_links": {
                    "self": {
                        "href": "/api/network/fc/logins/01056403-1383-bc4b-786a-93e8ea35969d/8b%3A21%3A2f%3A07%3A00%3A00%3A00%3A00"
                    }
                },
                "protocol": "fcp",
                "svm": {
                    "name": "svm1",
                    "uuid": "056403da-83a7-4b13-bc78-6a93e8ea3596",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/056403da-83a7-4b13-bc78-6a93e8ea3596"
                        }
                    },
                },
                "interface": {
                    "uuid": "01056403-1383-bc4b-786a-93e8ea35969d",
                    "_links": {
                        "self": {
                            "href": "/api/network/fc/interfaces/01056403-1383-bc4b-786a-93e8ea35969d"
                        }
                    },
                    "name": "lif2",
                    "wwpn": "8b:21:2f:07:00:00:00:00",
                },
                "initiator": {
                    "wwnn": "95:21:2f:07:00:00:00:00",
                    "wwpn": "8b:21:2f:07:00:00:00:00",
                },
            }
        )
    ]

## Classes

`class FcLogin (*args, **kwargs)`

  A Fibre Channel (FC) login represents a connection formed by an FC initiator that has successfully logged in to ONTAP. This represents the FC login on which higher-level protocols such as Fibre Channel Protocol and NVMe over Fibre Channel (NVMe/FC) rely.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves FC logins.

    ### Related ONTAP commands

    - `vserver fcp initiator show`

    ### Learn more

    - SAN: `DOC /network/fc/logins`
    - NVMe: `DOC /network/fc/logins`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves FC logins.

    ### Related ONTAP commands

    - `vserver fcp initiator show`

    ### Learn more

    - SAN: `DOC /network/fc/logins`
    - NVMe: `DOC /network/fc/logins`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves FC logins.

    ### Related ONTAP commands

    - `vserver fcp initiator show`

    ### Learn more

    - SAN: `DOC /network/fc/logins`
    - NVMe: `DOC /network/fc/logins`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves an FC login.

    ### Related ONTAP commands

    - `vserver fcp initiator show`

    ### Learn more

    - SAN: `DOC /network/fc/logins`
    - NVMe: `DOC /network/fc/logins`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class FcLoginSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FcLogin object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `igroups GET`

    The initiator groups in which the initiator is a member.

  `initiator GET`

    The initiator field of the fc_login.

  `interface GET`

    The interface field of the fc_login.

  `links GET`

    The links field of the fc_login.

  `protocol GET`

    The data protocol used to perform the login.

    Valid choices:

    - fc_nvme
    - fcp
  `svm GET`

    The svm field of the fc_login.